@@ -2,8 +2,8 @@
  * This is an OpenSSL-compatible implementation of the RSA Data Security,
  * Inc. MD5 Message-Digest Algorithm.
  *
- * Written by Solar Designer <solar@openwall.com> in 2001, and placed in
- * the public domain.  There's absolutely no warranty.
+ * Written by Solar Designer <solar at openwall.com> in 2001, and placed
+ * in the public domain.  There's absolutely no warranty.
  *
  * This differs from Colin Plumb's older public domain implementation in
  * that no 32-bit integer data type is required, there's no compile-time
@@ -48,7 +48,7 @@
  * memory accesses is just an optimization.  Nothing will break if it
  * doesn't work.
  */
-#if defined(__i386__) || defined(__vax__)
+#if defined(__i386__) || defined(__x86_64__) || defined(__vax__)
 #define SET(n) \
 	(*(MD5_u32plus *)&ptr[(n) * 4])
 #define GET(n) \
@@ -66,7 +66,7 @@
 
 /*
  * This processes one or more 64-byte data blocks, but does NOT update
- * the bit counters.  There're no alignment requirements.
+ * the bit counters.  There are no alignment requirements.
  */
 static void *body(MD5_CTX *ctx, void *data, unsigned long size)
 {
