@@ -2,8 +2,8 @@
  * This is an OpenSSL-compatible implementation of the RSA Data Security,
  * Inc. MD5 Message-Digest Algorithm.
  *
- * Written by Solar Designer <solar@openwall.com> in 2001, and placed in
- * the public domain.  See md5.c for more information.
+ * Written by Solar Designer <solar at openwall.com> in 2001, and placed
+ * in the public domain.  See md5.c for more information.
  */
 
 #ifdef HAVE_OPENSSL
@@ -11,8 +11,8 @@
 #elif !defined(_MD5_H)
 #define _MD5_H
 
-/* Any 32-bit or wider integer data type will do */
-typedef unsigned long MD5_u32plus;
+/* Any 32-bit or wider unsigned integer data type will do */
+typedef unsigned int MD5_u32plus;
 
 typedef struct {
 	MD5_u32plus lo, hi;
