@@ -5,6 +5,6 @@
 #ifndef _POP_TRANS_H
 #define _POP_TRANS_H
 
-extern int do_pop_trans(char *mailbox);
+extern int do_pop_trans(char *spool, char *mailbox);
 
 #endif
